[llvm-commits] CVS: llvm/include/llvm/Transforms/Utils/Local.h

Michael Brukman brukman at cs.uiuc.edu
Tue May 20 16:02:00 PDT 2003


Changes in directory llvm/include/llvm/Transforms/Utils:

Local.h updated: 1.8 -> 1.9

---
Log message:

Hopefully, the final fix for `[Pp]ropogate'.


---
Diffs of the changes:

Index: llvm/include/llvm/Transforms/Utils/Local.h
diff -u llvm/include/llvm/Transforms/Utils/Local.h:1.8 llvm/include/llvm/Transforms/Utils/Local.h:1.9
--- llvm/include/llvm/Transforms/Utils/Local.h:1.8	Tue Sep 24 10:51:54 2002
+++ llvm/include/llvm/Transforms/Utils/Local.h	Tue May 20 16:01:12 2003
@@ -12,13 +12,13 @@
 class Pass;
 
 //===----------------------------------------------------------------------===//
 //  Local constant propogation...
 //
 
 /// doConstantPropogation - Constant prop a specific instruction.  Returns true
 /// and potentially moves the iterator if constant propogation was performed.
 ///
-bool doConstantPropogation(BasicBlock::iterator &I);
+bool doConstantPropagation(BasicBlock::iterator &I);
 
 /// ConstantFoldTerminator - If a terminator instruction is predicated on a
 /// constant value, convert it into an unconditional branch to the constant
@@ -12,13 +12,13 @@
 
 //===----------------------------------------------------------------------===//
-//  Local constant propogation...
+//  Local constant propagation...
 //
 
@@ -12,13 +12,13 @@
 //
 
-/// doConstantPropogation - Constant prop a specific instruction.  Returns true
-/// and potentially moves the iterator if constant propogation was performed.
+/// doConstantPropagation - Constant prop a specific instruction.  Returns true
+/// and potentially moves the iterator if constant propagation was performed.
 ///





More information about the llvm-commits mailing list